==> office-ui-fabric-react-0.49.0.tgz: package/lib-amd/demo/pages/DetailsListPage/DetailsListPage.js <==
var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
define(["require", "exports", 'react', '../../../index', '../../components/index', '../../utilities/pageroute', '../../components/App/AppState', './examples/DetailsList.Basic.Example', './examples/DetailsList.CustomColumns.Example', './examples/DetailsList.CustomRows.Example', './examples/DetailsList.Advanced.Example'], function (require, exports, React, index_1, index_2, pageroute_1, AppState_1, DetailsList_Basic_Example_1, DetailsList_CustomColumns_Example_1, DetailsList_CustomRows_Example_1, DetailsList_Advanced_Example_1) {
    "use strict";
    var DetailsListBasicExampleCode = require('./examples/DetailsList.Basic.Example.tsx');
    var DetailsListCustomColumnsExampleCode = require('./examples/DetailsList.CustomColumns.Example.tsx');
    var DetailsListCustomRowsExampleCode = require('./examples/DetailsList.CustomRows.Example.tsx');
    var DetailsListAdvancedExampleCode = require('./examples/DetailsList.Advanced.Example.tsx');
    var DetailsListPage = (function (_super) {
        __extends(DetailsListPage, _super);
        function DetailsListPage() {
            _super.call(this);
            this._url = pageroute_1.getPageRouteFromState(AppState_1.AppState, 'Basic components', 'DetailsList');
        }
        DetailsListPage.prototype.render = function () {
            return (React.createElement(index_2.ComponentPage, {title: 'DetailsList', componentName: 'DetailsListExample', exampleCards: [
                React.createElement(index_2.ExampleCard, {title: 'Simple DetailsList with 500 items, filtering, marquee selection', isOptIn: true, code: DetailsListBasicExampleCode}, React.createElement(DetailsList_Basic_Example_1.DetailsListBasicExample, null)),
                React.createElement(index_2.ExampleCard, {title: 'Rendering custom item columns with sorting', isOptIn: true, code: DetailsListCustomColumnsExampleCode}, React.createElement(DetailsList_CustomColumns_Example_1.DetailsListCustomColumnsExample, null)),
                React.createElement(index_2.ExampleCard, {title: 'Rendering custom item rows', isOptIn: true, code: DetailsListCustomRowsExampleCode}, React.createElement(DetailsList_CustomRows_Example_1.DetailsListCustomRowsExample, null)),
                React.createElement(index_2.ExampleCard, {title: 'Advanced DetailsList of 5000 items, variable row heights', isOptIn: true, code: DetailsListAdvancedExampleCode}, React.createElement(DetailsList_Advanced_Example_1.DetailsListAdvancedExample, null))
            ], propertiesTables: [
                React.createElement(index_2.PropertiesTableSet, {componentName: 'DetailsList'})
            ], overview: React.createElement("div", null, React.createElement(index_1.Link, {target: '_blank', href: 'http://dev.office.com/fabric/components/DetailsList'}, "DetailsList"), React.createElement("span", null, " is a derivative of "), React.createElement(index_1.Link, {href: '#/examples/list'}, "List"), React.createElement("span", null, " and provides a sortable, filterable, justified table for rendering large sets of items. This component replaces the Table Component.")), route: this._url}));
        };
        return DetailsListPage;
    }(React.Component));
    exports.DetailsListPage = DetailsListPage;
});

==> office-ui-fabric-react-0.52.2.tgz: package/lib-amd/demo/pages/DetailsListPage/DetailsListPage.js <==
var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
define(["require", "exports", 'react', '../../../index', '../../components/index', '../../utilities/pageroute', '../../components/App/AppState', './examples/DetailsList.Basic.Example', './examples/DetailsList.CustomColumns.Example', './examples/DetailsList.CustomRows.Example', './examples/DetailsList.Advanced.Example'], function (require, exports, React, index_1, index_2, pageroute_1, AppState_1, DetailsList_Basic_Example_1, DetailsList_CustomColumns_Example_1, DetailsList_CustomRows_Example_1, DetailsList_Advanced_Example_1) {
    "use strict";
    var DetailsListBasicExampleCode = require('./examples/DetailsList.Basic.Example.tsx');
    var DetailsListCustomColumnsExampleCode = require('./examples/DetailsList.CustomColumns.Example.tsx');
    var DetailsListCustomRowsExampleCode = require('./examples/DetailsList.CustomRows.Example.tsx');
    var DetailsListAdvancedExampleCode = require('./examples/DetailsList.Advanced.Example.tsx');
    var DetailsListPage = (function (_super) {
        __extends(DetailsListPage, _super);
        function DetailsListPage() {
            _super.call(this);
            this._url = pageroute_1.getPageRouteFromState(AppState_1.AppState, 'Basic components', 'DetailsList');
        }
        DetailsListPage.prototype.render = function () {
            return (React.createElement(index_2.ComponentPage, {title: 'DetailsList', componentName: 'DetailsListExample', exampleCards: [
                React.createElement(index_2.ExampleCard, {title: 'Simple DetailsList with 500 items, filtering, marquee selection', isOptIn: true, code: DetailsListBasicExampleCode}, React.createElement(DetailsList_Basic_Example_1.DetailsListBasicExample, null)),
                React.createElement(index_2.ExampleCard, {title: 'Rendering custom item columns with sorting', isOptIn: true, code: DetailsListCustomColumnsExampleCode}, React.createElement(DetailsList_CustomColumns_Example_1.DetailsListCustomColumnsExample, null)),
                React.createElement(index_2.ExampleCard, {title: 'Rendering custom item rows', isOptIn: true, code: DetailsListCustomRowsExampleCode}, React.createElement(DetailsList_CustomRows_Example_1.DetailsListCustomRowsExample, null)),
                React.createElement(index_2.ExampleCard, {title: 'Advanced DetailsList of 5000 items, variable row heights', isOptIn: true, code: DetailsListAdvancedExampleCode}, React.createElement(DetailsList_Advanced_Example_1.DetailsListAdvancedExample, null))
            ], propertiesTables: [
                React.createElement(index_2.PropertiesTableSet, {componentName: 'DetailsList'})
            ], overview: React.createElement("div", null, React.createElement(index_1.Link, {target: '_blank', href: 'http://dev.office.com/fabric/components/DetailsList'}, "DetailsList"), React.createElement("span", null, " is a derivative of "), React.createElement(index_1.Link, {href: '#/examples/list'}, "List"), React.createElement("span", null, " and provides a sortable, filterable, justified table for rendering large sets of items. This component replaces the Table Component.")), route: this._url, isHeaderVisible: this.props.isHeaderVisible}));
        };
        return DetailsListPage;
    }(React.Component));
    exports.DetailsListPage = DetailsListPage;
});
